==> kie-wb-common-7.3.0.Final-project-sources.tar.gz: kie-wb-common-7.3.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-bpmn/kie-wb-common-stunner-bpmn-client/src/main/java/org/kie/workbench/common/stunner/bpmn/client/forms/fields/comboBoxEditor/ComboBoxFieldRenderer.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.bpmn.client.forms.fields.comboBoxEditor;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import com.google.gwt.user.client.ui.IsWidget;
import org.kie.workbench.common.forms.dynamic.client.rendering.renderers.selectors.SelectorFieldRenderer;
import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.StringSelectorOption;
import org.kie.workbench.common.stunner.bpmn.client.forms.util.ListBoxValues;
import org.kie.workbench.common.stunner.bpmn.forms.model.ComboBoxFieldDefinition;

@Dependent
public class ComboBoxFieldRenderer
        extends SelectorFieldRenderer<ComboBoxFieldDefinition, StringSelectorOption, String> {

    private ComboBoxWidgetView view;

    private ListBoxValues valueListBoxValues;

    @Inject
    public ComboBoxFieldRenderer(final ComboBoxWidgetView comboBoxEditor) {
        this.view = comboBoxEditor;
    }

    @Override
    protected void refreshInput(Map<String, String> optionsValues,
                                String defaultValue) {
        List<String> values = new ArrayList<String>(optionsValues.keySet());
        java.util.Collections.sort(values);
        setComboBoxValues(values);
    }

    protected void setComboBoxValues(final List<String> values) {
        valueListBoxValues = new ListBoxValues(ComboBoxWidgetView.CUSTOM_PROMPT,
                                               "Edit" + " ",
                                               null);
        valueListBoxValues.addValues(values);
        view.setComboBoxValues(valueListBoxValues);
    }

    @Override
    public String getName() {
        return ComboBoxFieldDefinition.FIELD_TYPE.getTypeName();
    }

    @Override
    public void initInputWidget() {
        view.setReadOnly(field.getReadOnly());
        refreshSelectorOptions();
    }

    @Override
    public IsWidget getInputWidget() {
        return (ComboBoxWidgetViewImpl) view;
    }

    @Override
    public String getSupportedCode() {
        return ComboBoxFieldDefinition.FIELD_TYPE.getTypeName();
    }

    @Override
    public IsWidget getPrettyViewWidget() {
        initInputWidget();
        return getInputWidget();
    }

    @Override
    protected void setReadOnly(boolean readOnly) {
        view.setReadOnly(readOnly);
    }

    @Override
    public Class<ComboBoxFieldDefinition> getSupportedFieldDefinition() {
        return ComboBoxFieldDefinition.class;
    }
}

==> kie-wb-common-7.25.0.Final-project-sources.tar.gz: kie-wb-common-7.25.0.Final/kie-wb-common-stunner/kie-wb-common-stunner-sets/kie-wb-common-stunner-bpmn/kie-wb-common-stunner-bpmn-client/src/main/java/org/kie/workbench/common/stunner/bpmn/client/forms/fields/comboBoxEditor/ComboBoxFieldRenderer.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.stunner.bpmn.client.forms.fields.comboBoxEditor;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.kie.workbench.common.stunner.bpmn.forms.model.ComboBoxFieldDefinition;

@Dependent
public class ComboBoxFieldRenderer
        extends AbstractComboBoxFieldRenderer<ComboBoxFieldDefinition> {

    public static final String TYPE_NAME = ComboBoxFieldDefinition.FIELD_TYPE.getTypeName();

    @Inject
    public ComboBoxFieldRenderer(final ComboBoxWidgetView comboBoxEditor) {
        super(comboBoxEditor);
    }

    @Override
    public String getName() {
        return TYPE_NAME;
    }

    @Override
    public String getSupportedCode() {
        return TYPE_NAME;
    }

    @Override
    public Class<ComboBoxFieldDefinition> getSupportedFieldDefinition() {
        return ComboBoxFieldDefinition.class;
    }
}
